@@ -10,15 +10,15 @@
 //!              _______
 //!             /   0   \
 //!     _______/         \_______
-//!    /  -1   \ 1    -1 /   1   \
+//!    /  -1   \ -1    1 /   1   \
 //!   /         \_______/         \
-//!   \ 1     0 /   x   \ 0    -1 /
+//!   \ 0     1 /   x   \ -1    0 /
 //!    \_______/         \_______/
 //!    /  -1   \ y     z /   1   \
 //!   /         \_______/         \
-//!   \ 0     1 /   0   \ -1    0 /
+//!   \ 1     0 /   0   \ 0    -1 /
 //!    \_______/         \_______/
-//!            \ -1    1 /
+//!            \ 1    -1 /
 //!             \_______/
 //! ```
 //!
@@ -47,31 +47,31 @@ use core::panic;
 ///                             /    0    \
 ///                            /           \
 ///                  _________/    Ring2    \_________
-///                 /   -1    \ 2        -2 /    1    \
+///                 /   -1    \ -2        2 /    1    \
 ///                /           \           /           \
 ///      _________/    Ring2    \_________/    Ring2    \_________
-///     /   -2    \ 0        -1 /    0    \ 1        -2 /    2    \
+///     /   -2    \ -1        2 /    0    \ -2        1 /    2    \
 ///    /           \           /           \           /           \
 ///   /    Ring2    \_________/    Ring1    \_________/    Ring2    \
-///   \ -2        0 /   -1    \ 1        -1 /    1    \ 0        -2 /
+///   \ 0         2 /   -1    \ -1        1 /    1    \ -2        0 /
 ///    \           /           \           /           \           /
 ///     \_________/    Ring1    \_________/    Ring1    \_________/
-///     /   -2    \ 1         0 /    0    \ 0        -1 /    2    \
+///     /   -2    \ 0         1 /    0    \ -1        0 /    2    \
 ///    /           \           /           \           /           \
 ///   /    Ring2    \_________/             \_________/    Ring2    \
 ///   \ 1         1 /   -1    \ 0         0 /    1    \ -1       -1 /
 ///    \           /           \           /           \           /
 ///     \_________/    Ring1    \_________/    Ring1    \_________/
-///     /   -2    \ 0         1 /    0    \ -1        0 /    2    \
+///     /   -2    \ 1         0 /    0    \ 0        -1 /    2    \
 ///    /           \           /           \           /           \
 ///   /    Ring2    \_________/    Ring1    \_________/    Ring2    \
-///   \ 0         2 /   -1    \ -1        1 /    1    \ -2        0 /
+///   \ 2         0 /   -1    \ 1        -1 /    1    \ 0        -2 /
 ///    \           /           \           /           \           /
 ///     \_________/    Ring2    \_________/    Ring2    \_________/
-///               \ -1        2 /    0    \ 0         1 /
+///               \ 2        -1 /    0    \ 1        -2 /
 ///                \           /           \           /
 ///                 \_________/    Ring2    \_________/
-///                           \ -2        2 /
+///                           \ 2        -2 /
 ///                            \           /
 ///                             \_________/
 ///  ```
@@ -273,31 +273,31 @@ mod tests {
 	///                             /    0    \
 	///                            /           \
 	///                  _________/     C:1     \_________
-	///                 /   -1    \ 2        -2 /    1    \
+	///                 /   -1    \ -2        2 /    1    \
 	///                /           \           /           \
 	///      _________/     C:2     \_________/     C:14    \_________
-	///     /   -2    \ 2        -1 /    0    \ 1        -2 /    2    \
+	///     /   -2    \ -1        2 /    0    \ -2        1 /    2    \
 	///    /           \           /           \           /     E     \
 	///   /     C:1     \_________/     C:1     \_________/     C:1     \
-	///   \ 2         0 /   -1    \ 1        -1 /    1    \ 0        -2 /
+	///   \ 0         2 /   -1    \ -1        1 /    1    \ -2        0 /
 	///    \           /           \           /           \           /
 	///     \_________/     C:7     \_________/     C:15    \_________/
-	///     /   -2    \ 1         0 /    0    \ 0        -1 /    2    \
+	///     /   -2    \ 0         1 /    0    \ -1        0 /    2    \
 	///    /           \           /     S     \           /           \
 	///   /     C:8     \_________/     C:1     \_________/     C:1     \
 	///   \ 1         1 /   -1    \ 0         0 /    1    \ -1       -1 /
 	///    \           /           \           /           \           /
 	///     \_________/     C:6     \_________/     C:14    \_________/
-	///     /   -2    \ 0         1 /    0    \ -1        0 /    2    \
+	///     /   -2    \ 1         0 /    0    \ 0        -1 /    2    \
 	///    /           \           /           \           /           \
 	///   /     C:1     \_________/     C:2     \_________/     C:1     \
-	///   \ 0         2 /   -1    \ -1        1 /    1    \ -2        0 /
+	///   \ 2         0 /   -1    \ 1        -1 /    1    \ 0        -2 /
 	///    \           /           \           /           \           /
 	///     \_________/     C:3     \_________/     C:1     \_________/
-	///               \ -1        2 /    0    \ -2        1 /
+	///               \ 2        -1 /    0    \ 1        -2 /
 	///                \           /           \           /
 	///                 \_________/     C:1     \_________/
-	///                           \ -2        2 /
+	///                           \ 2        -2 /
 	///                            \           /
 	///                             \_________/
 	///  ```
@@ -305,34 +305,34 @@ mod tests {
 		let start_node: (i32, i32, i32) = (0, 0, 0);
 		let mut nodes: HashMap<(i32, i32, i32), f32> = HashMap::new();
 		nodes.insert((0, 0, 0), 1.0);
-		nodes.insert((0, 1, -1), 1.0);
-		nodes.insert((1, 0, -1), 15.0);
-		nodes.insert((1, -1, 0), 14.0);
-		nodes.insert((0, -1, 1), 2.0);
-		nodes.insert((-1, 0, 1), 6.0);
-		nodes.insert((-1, 1, 0), 7.0);
-		nodes.insert((0, 2, -2), 1.0);
-		nodes.insert((1, 1, -2), 14.0);
-		nodes.insert((2, 0, -2), 1.0);
-		nodes.insert((2, -1, -1), 1.0);
-		nodes.insert((2, -2, 0), 1.0);
-		nodes.insert((1, -2, 1), 1.0);
+		nodes.insert((0, -1, 1), 1.0);
+		nodes.insert((1, -1, 0), 15.0);
+		nodes.insert((1, 0, -1), 14.0);
+		nodes.insert((0, 1, -1), 2.0);
+		nodes.insert((-1, 1, 0), 6.0);
+		nodes.insert((-1, 0, 1), 7.0);
 		nodes.insert((0, -2, 2), 1.0);
-		nodes.insert((-1, -1, 2), 3.0);
-		nodes.insert((-2, 0, 2), 1.0);
-		nodes.insert((-2, 1, 1), 8.0);
+		nodes.insert((1, -2, 1), 14.0);
+		nodes.insert((2, -2, 0), 1.0);
+		nodes.insert((2, -1, -1), 1.0);
+		nodes.insert((2, 0, -2), 1.0);
+		nodes.insert((1, 1, -2), 1.0);
+		nodes.insert((0, 2, -2), 1.0);
+		nodes.insert((-1, 2, -1), 3.0);
 		nodes.insert((-2, 2, 0), 1.0);
-		nodes.insert((-1, 2, -1), 2.0);
-		let end_node: (i32, i32, i32) = (2, 0, -2);
+		nodes.insert((-2, 1, 1), 8.0);
+		nodes.insert((-2, 0, 2), 1.0);
+		nodes.insert((-1, -1, 2), 2.0);
+		let end_node: (i32, i32, i32) = (2, -2, 0);
 		let rings = 2;
 		let best = astar_path(start_node, nodes, end_node, rings);
 		let actual = vec![
 			(0, 0, 0),
-			(0, -1, 1),
-			(1, -2, 1),
-			(2, -2, 0),
-			(2, -1, -1),
+			(0, 1, -1),
+			(1, 1, -2),
 			(2, 0, -2),
+			(2, -1, -1),
+			(2, -2, 0),
 		];
 		assert_eq!(actual, best);
 	}
